==> vcremote-utils-1.0.7.tgz: package/process-logger.js <==
﻿/**
* ******************************************************
*                                                       *
*   Copyright (C) Microsoft. All rights reserved.       *
*                                                       *
*******************************************************
*/
/// <reference path="../typings/nconf.d.ts" />
/// <reference path="../typings/node.d.ts" />
/// <reference path="../typings/vcremote-utils.d.ts" />
"use strict";
var fs = require("fs");
var path = require("path");
var vcremoteUtility = require("./resources-manager");
var resources = vcremoteUtility.ResourcesManager;

var VCRemoteUtility;
(function (VCRemoteUtility) {
    var ProcessLogger = (function () {
        function ProcessLogger() {
            this._stream = null;
        }
        ProcessLogger.prototype.begin = function (logDir, logFileName, language, proc) {
            var pathToLog = path.join(logDir, logFileName);
            this._stream = fs.createWriteStream(pathToLog);
            this._stream.on("error", function (err) {
                console.error(resources.getStringForLanguage(language, "ProcessLogError"), pathToLog, err);
            });
            var me = this;
            proc.stdout.on("data", function (data) {
                me.log(data);
            });
            proc.stderr.on("data", function (data) {
                me.log(data);
            });
            proc.on("exit", function (code) {
                if (code) {
                    me.log(resources.getStringForLanguage(language, "LoggedProcessTerminatedWithCode", code));
                }

                me.end();
            });
        };

        ProcessLogger.prototype.end = function () {
            if (this._stream) {
                this._stream.end();
            }

            this._stream = null;
        };

        ProcessLogger.prototype.log = function (message) {
            if (this._stream) {
                this._stream.write(message);
            }
        };
        return ProcessLogger;
    })();
    VCRemoteUtility.ProcessLogger = ProcessLogger;
})(VCRemoteUtility || (VCRemoteUtility = {}));

module.exports = VCRemoteUtility;

==> vcremote-utils-1.0.10.tgz: package/process-logger.js <==
/**
  * ******************************************************
  *                                                       *
  *   Copyright (C) Microsoft. All rights reserved.       *
  *                                                       *
  *******************************************************
  */
"use strict";
const fs = require("fs");
const path = require("path");
const vcremoteUtility = require("./resources-manager");
var resources = vcremoteUtility.ResourcesManager;
var VCRemoteUtility;
(function (VCRemoteUtility) {
    class ProcessLogger {
        constructor() {
            this._stream = null;
        }
        begin(logDir, logFileName, language, proc) {
            var pathToLog = path.join(logDir, logFileName);
            this._stream = fs.createWriteStream(pathToLog);
            this._stream.on("error", function (err) {
                console.error(resources.getStringForLanguage(language, "ProcessLogError"), pathToLog, err);
            });
            var me = this;
            proc.stdout.on("data", function (data) {
                me.log(data);
            });
            proc.stderr.on("data", function (data) {
                me.log(data);
            });
            proc.on("exit", function (code) {
                if (code) {
                    me.log(resources.getStringForLanguage(language, "LoggedProcessTerminatedWithCode", code));
                }
                me.end();
            });
        }
        end() {
            if (this._stream) {
                this._stream.end();
            }
            this._stream = null;
        }
        log(message) {
            if (this._stream) {
                this._stream.write(message);
            }
        }
    }
    VCRemoteUtility.ProcessLogger = ProcessLogger;
})(VCRemoteUtility || (VCRemoteUtility = {}));
module.exports = VCRemoteUtility;
